.. _api:

API Reference
=============

Some words on API reference.

**Contents**:

.. toctree::
    :maxdepth: 2

    processor
    processor_utils
    interfacer
    data_io
    guis
    multi_proc
    utilities
